@@ -30,13 +30,29 @@ stode         <- function(y, time=0, func, parms=NULL,
         initforc = NULL, fcontrol = NULL, ...)  {
 
 ## check input
+  if (is.list(func)) {            
+      if (!is.null(jacfunc) & "jacfunc" %in% names(func))
+         stop("If 'func' is a list that contains jacfunc, argument 'jacfunc' should be NULL")
+      if (!is.null(initfunc) & "initfunc" %in% names(func))
+         stop("If 'func' is a list that contains initfunc, argument 'initfunc' should be NULL")
+      if (!is.null(dllname) & "dllname" %in% names(func))
+         stop("If 'func' is a list that contains dllname, argument 'dllname' should be NULL")
+      if (!is.null(initforc) & "initforc" %in% names(func))
+         stop("If 'func' is a list that contains initforc, argument 'initforc' should be NULL")
+     if (! is.null(func$jacfunc))  jacfunc <- func$jacfunc
+     if (! is.null(func$initfunc)) initfunc <- func$initfunc
+     if (! is.null(func$dllname))  dllname <- func$dllname
+     if (! is.null(func$initforc)) initforc <- func$initforc
+     func <- func$func
+  }
+
   if (!is.numeric(y))
     stop("`y' must be numeric")
   n <- length(y)
   if (! is.null(time)&&!is.numeric(time))
     stop("`time' must be NULL or numeric")
-  if (!is.function(func) && !is.character(func))
-    stop("`func' must be a function or character vector")
+  if (!CheckFunc(func))
+    stop("`func' must be a function or character vector or a compiled function")
   if (is.character(func) && (is.null(dllname) || !is.character(dllname)))
     stop("You need to specify the name of the dll or shared library where 'func' can be found (without extension)")
   if (!is.numeric(maxiter))
@@ -49,8 +65,8 @@ stode         <- function(y, time=0, func, parms=NULL,
     stop("`atol' must be numeric")
   if (!is.numeric(ctol))
     stop("`ctol' must be numeric")
-  if (!is.null(jacfunc) && !(is.function(jacfunc) || is.character(jacfunc)))
-    stop("`jacfunc' must be a function or character vector")
+  if (!is.null(jacfunc) & !CheckFunc(jacfunc))
+    stop("`jacfunc' must be a function or character vector or a compiled function")
   if (length(atol) > 1 && length(atol) != n)
     stop("`atol' must either be a scalar, or as long as `y'")
   if (length(rtol) > 1 && length(rtol) != n)
@@ -105,14 +121,20 @@ stode         <- function(y, time=0, func, parms=NULL,
   ModelInit <- NULL
   ModelForc <- NULL
   Forc <- NULL
-  if ( ! is.null(dllname)) {
-     if (is.loaded(initfunc, PACKAGE = dllname,
+  if (is.compiled(func)) {
+    if(! is.null(initfunc)) {
+     if (class(initfunc) == "CFunc")
+        ModelInit <- body(initfunc)[[2]]
+
+     else if (is.loaded(initfunc, PACKAGE = dllname,
          type = "") || is.loaded(initfunc, PACKAGE = dllname,
          type = "Fortran"))
          ModelInit <- getNativeSymbolInfo(initfunc, PACKAGE = dllname)$address
-
+     }
      if (! is.null(initforc))  {
-       if (is.loaded(initforc, PACKAGE = dllname,
+       if (class(initforc) == "CFunc")
+          ModelForc <- body(initforc)[[2]]
+       else if (is.loaded(initforc, PACKAGE = dllname,
                 type = "") || is.loaded(initforc, PACKAGE = dllname,
                 type = "Fortran"))
        ModelForc <- getNativeSymbolInfo(initforc, PACKAGE = dllname)$address
@@ -126,19 +148,23 @@ stode         <- function(y, time=0, func, parms=NULL,
 
 ## If func is a character vector, then copy its value to funcname
 ## check to make sure it describes a function in a loaded dll
-  if (is.character(func)) {
+  if (is.compiled(func)) {
     funcname <- func
      # get the pointer and put it in func
-    if(is.loaded(funcname, PACKAGE = dllname)) {
+    if (class(func) == "CFunc")
+      Func <- body(func)[[2]]
+    else if(is.loaded(funcname, PACKAGE = dllname)) {
       Func <- getNativeSymbolInfo(funcname, PACKAGE = dllname)$address
      } else
        stop(paste("cannot calculate steady-state: dyn function not loaded: ",funcname))
        # is there a jacobian?
     if (!is.null(jacfunc)) {
-      if (!is.character(jacfunc))
+      if (!is.compiled(jacfunc))
          stop("If 'func' is dynloaded, so must 'jacfunc' be")
       jacfuncname <- jacfunc
-      if(is.loaded(jacfuncname, PACKAGE = dllname)) {
+      if (class(jacfunc) == "CFunc")
+        JacFunc <- body(jacfunc)[[2]]
+      else if(is.loaded(jacfuncname, PACKAGE = dllname)) {
         JacFunc <- getNativeSymbolInfo(jacfuncname, PACKAGE = dllname)$address
       } else
         stop(paste("cannot calculate steady-state: jacobian function not loaded ",jacfunc))
@@ -252,7 +278,7 @@ stode         <- function(y, time=0, func, parms=NULL,
   attributes(out)<-NULL
   if (Nglobal > 0) {
 
-    if (!is.character(func)) {         # if a DLL: already done...
+    if (!is.character(func) & ! class(func) == "CFunc") {         # if a DLL: already done...
       y <- out                      # state variables of this time step
       if(ynames)  attr(y,"names")  <-  Ynames
       out2 <- Func2(time, y)[-1]
