@@ -12,13 +12,26 @@ stodes <- function(y, time = 0, func, parms = NULL,
         ipar = NULL, nout = 0, outnames = NULL, forcings = NULL, 
         initforc = NULL, fcontrol = NULL, spmethod = "yale", control = NULL, ...)  {
 ## check input
+  if (is.list(func)) {            
+      if (!is.null(initfunc) & "initfunc" %in% names(func))
+         stop("If 'func' is a list that contains initfunc, argument 'initfunc' should be NULL")
+      if (!is.null(dllname) & "dllname" %in% names(func))
+         stop("If 'func' is a list that contains dllname, argument 'dllname' should be NULL")
+      if (!is.null(initforc) & "initforc" %in% names(func))
+         stop("If 'func' is a list that contains initforc, argument 'initforc' should be NULL")
+     if (! is.null(func$initfunc)) initfunc <- func$initfunc
+     if (! is.null(func$dllname )) dllname <- func$dllname
+     if (! is.null(func$initforc)) initforc <- func$initforc
+     func <- func$func
+  }
+
   if (!is.numeric(y))
     stop("`y' must be numeric")
   n <- length(y)
   if (! is.null(time)&&!is.numeric(time))
     stop("`time' must be NULL or numeric")
-  if (!is.function(func) && !is.character(func))
-    stop("`func' must be a function or character vector")
+  if (!CheckFunc(func))
+    stop("`func' must be a function or character vector or a compiled function")
   if (is.character(func) && (is.null(dllname) || !is.character(dllname)))
     stop("You need to specify the name of the dll or shared library where func can be found (without extension)")
   if (!is.numeric(maxiter))
@@ -175,8 +188,11 @@ stodes <- function(y, time = 0, func, parms = NULL,
   ModelInit <- NULL
   ModelForc <- NULL
   Forc <- NULL
-  if(!is.null(dllname)) {
-     if (is.loaded(initfunc, PACKAGE = dllname,
+  if(is.compiled(func) & ! is.null(initfunc)) {
+     if (class(initfunc) == "CFunc")
+        ModelInit <- body(initfunc)[[2]]
+  
+     else if (is.loaded(initfunc, PACKAGE = dllname,
                 type = "") || is.loaded(initfunc, PACKAGE = dllname,
                 type = "Fortran"))
        ModelInit <- getNativeSymbolInfo(initfunc, PACKAGE = dllname)$address
@@ -184,16 +200,20 @@ stodes <- function(y, time = 0, func, parms = NULL,
 
 ## If func is a character vector, then copy its value to funcname
 ## check to make sure it describes a function in a loaded dll
-  if (is.character(func)) {
+  if (is.compiled(func)) {
     funcname <- func
       # get the pointer and put it in func
-    if(is.loaded(funcname, PACKAGE = dllname)) {
+     if (class(func) == "CFunc")
+      Func <- body(func)[[2]]
+     else if(is.loaded(funcname, PACKAGE = dllname)) {
        Func <- getNativeSymbolInfo(funcname, PACKAGE = dllname)$address
     } else
       stop(paste("cannot calculate steady-state: dyn function not loaded: ",funcname))
 
      if (! is.null(initforc))  {
-       if (is.loaded(initforc, PACKAGE = dllname,
+       if (class(initforc) == "CFunc")
+          ModelForc <- body(initforc)[[2]]
+       else if (is.loaded(initforc, PACKAGE = dllname,
                 type = "") || is.loaded(initforc, PACKAGE = dllname,
                 type = "Fortran"))
        ModelForc <- getNativeSymbolInfo(initforc, PACKAGE = dllname)$address
@@ -307,7 +327,7 @@ stodes <- function(y, time = 0, func, parms = NULL,
 
   attributes(out)<-NULL
   if (Nglobal > 0) {
-    if (!is.character(func)) {      # if a DLL: already done...
+    if (!is.character(func) & ! class(func) == "CFunc") {      # if a DLL: already done...
       y <- out                      # state variables of this time step
       if(ynames)  attr(y,"names")  <-  Ynames
       out2 <- Func2(time, y)[-1]
